require "hubspot/version"
require "hubspot/http_request"

module Hubspot
  def self.configure
    self.configuration ||= Configuration.new
    yield(configuration)
  end

  class << self
    attr_accessor :configuration

    def get(url, options)
      raise ArgumentError, "Url can't be blank!" if url.blank?
      raise ArgumentError, "Options can't be blank!" if options.blank?

      Base.new.send(:get, url, options)
    end

    def post(url, options)
      raise ArgumentError, "Url can't be blank!" if url.blank?
      raise ArgumentError, "Options can't be blank!" if options.blank?

      Base.new.send(:post, url, options)
    end
  end

  class Configuration
    attr_accessor :hapikey, :user_name, :password, :address, :port

    def hubspot?
      ActionMailer::Base.delivery_method == :hubspot
    end

    def hubspot_transaction_email?
      ActionMailer::Base.delivery_method == :hubspot_transaction_email
    end
  end

  class Base < HttpRequest
    def send(verb = :get, url, options)
      self.method(verb).call(url, options)
    end
  end
end

require "hubspot/railtie" if defined?(Rails::Railtie)
require "hubspot/mailer" if defined?(ActionMailer::Base)
require "hubspot/transaction_email/mailer" if defined?(ActionMailer::Base)
